.. _trojanvision.models:

models
=======

.. currentmodule:: trojanvision.models

.. toctree::
   :maxdepth: 2

   torchvision
   nas
   others

.. autofunction:: add_argument
.. autofunction:: create
.. autofunction:: output_available_models

.. autoclass:: ImageModel
   :members:
